// SPDX-License-Identifier: GPL-2.0
#ifndef TESTDIVESITEDUPLICATION_H
#define TESTDIVESITEDUPLICATION_H

#include <QTest>

class TestDiveSiteDuplication : public QObject {
	Q_OBJECT
private slots:
	void testReadV2();
};

#endif // TESTDIVESITEDUPLICATION_H
